@@ -189,7 +189,7 @@ class Experimento:
         self.matriz_recurrencia_region_cuadriculada = None
         self.matriz_cuadriculada = None
         self.matriz_cuadriculada_regiones_preferidas = None
-        self.matriz_cuadriculada_solo_regiones_preferidas
+        self.matriz_cuadriculada_solo_regiones_preferidas = None
         self.matriz_cuadriculada_solo_regiones_no_preferidas = None
 
         self.visitas_regiones_preferidas = None
@@ -1553,7 +1553,7 @@ class Experimento:
 
         elif grafica == 'region_cuadricula_3d_solo_regiones_no_preferidas':
 
-            print("Entro a regionCuadricula3d, solo regiones preferidas")
+            print("Entro a regionCuadricula3d, solo regiones no preferidas")
 
             rot_grafica_3d = rotacion_grafica_3d
 
